# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["DocumentCreateResponse"]


class DocumentCreateResponse(BaseModel):
    id: str
    """Unique job identifier. Example: f47ac10b-58cc-4372-a567-0e02b2c3d479"""
